# Generated by Django 4.1.7 on 2023-07-12 16:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("trackstats", "0003_alter_model_fields"),
    ]

    operations = [
        migrations.AlterField(
            model_name="domain",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="metric",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="statisticbydate",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="statisticbydateandobject",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
